==> haskell-string-conversions-0.4.0.1-270.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-string-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-conversions
version:              0.4.0.1
visibility:           public
id:                   string-conversions-0.4.0.1-3kMZcJjj5P5Da5apuKM9D9
key:                  string-conversions-0.4.0.1-3kMZcJjj5P5Da5apuKM9D9
license:              BSD-3-Clause
maintainer:           soenkehahn@gmail.com
author:               Sönke Hahn
homepage:             https://github.com/soenkehahn/string-conversions#readme
synopsis:             Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.

category:             Data
abi:                  4ffadda13cafb68fe31e4c66b2c0bb5b
exposed:              True
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic

import-dirs:          /usr/lib/ghc-9.6.6/site-local/string-conversions-0.4.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/string-conversions-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-conversions
hs-libraries:         HSstring-conversions-0.4.0.1-3kMZcJjj5P5Da5apuKM9D9
depends:
    base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:
    /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock

haddock-html:         /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-conversions-0.4.0.1-271-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-string-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-conversions
version:              0.4.0.1
visibility:           public
id:                   string-conversions-0.4.0.1-LTGnXQU7F9LF7QuuvvXPma
key:                  string-conversions-0.4.0.1-LTGnXQU7F9LF7QuuvvXPma
license:              BSD-3-Clause
maintainer:           soenkehahn@gmail.com
author:               Sönke Hahn
homepage:             https://github.com/soenkehahn/string-conversions#readme
synopsis:             Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.

category:             Data
abi:                  640cc66585aa464f07fdf8cf5b3a1951
exposed:              True
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic

import-dirs:          /usr/lib/ghc-9.6.6/site-local/string-conversions-0.4.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/string-conversions-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-conversions
hs-libraries:         HSstring-conversions-0.4.0.1-LTGnXQU7F9LF7QuuvvXPma
depends:
    base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:
    /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock

haddock-html:         /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
